Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorCentro

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private db As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objCentro">Objeto Centro que contiene los datos a guardar</param>
        ''' <returns>
        ''' Booleano que indica si se ha guardado el registro correctamente (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function Guardar(ByVal objCentro As CENTRO) As Boolean
            Try
                If objCentro.ID_CENTRO.ToString.Equals("0") Then
                    db.AddToCENTRO(objCentro)
                Else
                    Dim oCentro As New CENTRO()
                    oCentro = LoadByPK(objCentro.ID_CENTRO)
                    If Not oCentro.DT_FECBAJA.Equals(objCentro.DT_FECBAJA) Then
                        If Not ValidarBaja(objCentro.ID_CENTRO) Then Return False
                    End If
                    With oCentro
                        .DS_TITULO = objCentro.DS_TITULO
                        .DS_CENTRO = objCentro.DS_CENTRO
                        .DS_DIRECCION = objCentro.DS_DIRECCION
                        .DS_TELEFONO = objCentro.DS_TELEFONO
                        .DS_EMAIL = objCentro.DS_EMAIL
                        .DS_USUMOD = objCentro.DS_USUMOD
                        .DT_FECBAJA = objCentro.DT_FECBAJA
                        .GO_LONGITUD = objCentro.GO_LONGITUD
                        .GO_LATITUD = objCentro.GO_LATITUD
                    End With
                End If
                db.SaveChanges()
                Return True
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_CENTRO">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Centro encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_CENTRO As Integer) As CENTRO
            Try
                Return (From p In db.CENTRO Where p.ID_CENTRO = iD_CENTRO Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Centro encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String) As List(Of CENTRO)
            Try
                Return (From p In db.CENTRO Where p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros activos
        ''' </summary>
        ''' <returns>
        ''' Lista de objetos Centro encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadActivos() As List(Of CENTRO)
            Try
                Return (From p In db.CENTRO Where (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p Order By p.DS_TITULO).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de un combobox con centros
        ''' </summary>
        ''' <param name="comboCentros">Combobox a cargar</param>
        ''' <param name="boActivos">Indicador para filtrar por activos (True) o desactivos (False)</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub CargarCBCentros(ByVal comboCentros As Controls.ComboBox, ByVal boActivos As Boolean)
            Try
                Dim lCentros As List(Of CENTRO)
                If boActivos Then
                    lCentros = LoadActivos()
                Else
                    lCentros = db.CENTRO.ToList
                End If
                Dim item As New CENTRO
                item.ID_CENTRO = 0
                item.DS_TITULO = MensajeResource("msg_seleccione_centro")
                lCentros.Insert(0, item)
                comboCentros.DisplayMemberPath = "DS_TITULO"
                comboCentros.SelectedValuePath = "ID_CENTRO"
                comboCentros.ItemsSource = lCentros
                comboCentros.SelectedIndex = 0
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la validación por si se puede dar de baja un centro
        ''' </summary>
        ''' <param name="idCentro">Id del centro a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si la baja es válida (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Function ValidarBaja(ByVal idCentro As Integer) As Boolean
            Try
                Dim listIns As List(Of INSTALACION) = (From p In db.INSTALACION Where p.ID_CENTRO = idCentro And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p).ToList
                If listIns.Count = 0 Then
                    Dim listOfe As List(Of OFERTA) = (From p In db.OFERTA Where p.ID_CENTRO = idCentro And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p).ToList
                    If listOfe.Count = 0 Then
                        Dim listUsu As List(Of USUARIO) = (From p In db.USUARIO Where p.ID_CENTRO = idCentro And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p).ToList
                        If listUsu.Count = 0 Then
                            Return True
                        Else
                            MensajeInfo("msg_centro_rel_usu")
                            Return False
                        End If
                    Else
                        MensajeInfo("msg_centro_rel_ofer")
                        Return False
                    End If
                Else
                    MensajeInfo("msg_centro_rel_ins")
                    Return False
                End If

            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace