Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorComentario

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="idComentario">Id del comentario a guardar</param>
        ''' <param name="boolBaja">Indicador de si damos de baja el registro (True) o si lo activamos (False)</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal idComentario As Integer, ByVal boolBaja As Boolean)
            Try
                Dim oCom As New COMENTARIO()
                oCom = LoadByPK(idComentario)
                With oCom
                    If boolBaja Then
                        .BO_ACTIVO = "0"
                        .DT_FECBAJA = Now
                    Else
                        .BO_ACTIVO = "1"
                        .DT_FECBAJA = Nothing
                    End If
                    .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                End With
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_COMENTARIO">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Comentario encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_COMENTARIO As Integer) As COMENTARIO
            Try
                Return (From p In objModel.COMENTARIO Where p.ID_COMENTARIO = iD_COMENTARIO Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_COMENTARIO">Cadena con parte del comentario a filtrar</param>
        ''' <param name="iD_USUARIO">Id del autor de un comentario a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Comentario encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_COMENTARIO As String, ByVal iD_USUARIO As Integer) As List(Of COMENTARIO)
            Try
                Return (From p In objModel.COMENTARIO Where (p.DS_COMENTARIO.Contains(dS_COMENTARIO) Or dS_COMENTARIO = String.Empty) _
                                And (p.USUARIO.ID_USUARIO = iD_USUARIO Or iD_USUARIO = 0) _
                                Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace