Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorCompeticion

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objCompeticion">Objeto Competición que contiene los datos a guardar</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objCompeticion As COMPETICION)
            Try
                If objCompeticion.ID_COMPETICION.ToString.Equals("0") Then
                    objModel.AddToCOMPETICION(objCompeticion)
                Else
                    Dim oComp As New COMPETICION()
                    oComp = CType((From p In objModel.COMPETICION Where p.ID_COMPETICION = objCompeticion.ID_COMPETICION Select p).FirstOrDefault, COMPETICION)
                    With oComp
                        .DS_TITULO = objCompeticion.DS_TITULO
                        .DS_COMPETICION = objCompeticion.DS_COMPETICION
                        .DS_USUMOD = objCompeticion.DS_USUMOD
                        .DT_FECHA = objCompeticion.DT_FECHA
                        .OB_RECORRIDO = objCompeticion.OB_RECORRIDO
                    End With
                End If
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_COMPETICION">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Competicion encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_COMPETICION As Integer) As COMPETICION
            Try
                Return (From p In objModel.COMPETICION Where p.ID_COMPETICION = iD_COMPETICION Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Competicion encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String) As List(Of COMPETICION)
            Try
                Return (From p In objModel.COMPETICION Where (p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty) Select p Order By p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace