Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorInstalacion

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objInstalacion">Objeto Instalación que contiene los datos a guardar</param>
        ''' <param name="iD_CENTRO">Id del centro al que pertenece la instalación</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objInstalacion As INSTALACION, ByVal iD_CENTRO As Integer)
            Try
                Dim objCtrlCentro As New Controlador.ControladorCentro
                If objInstalacion.ID_INSTALACION.ToString.Equals("0") Then
                    objInstalacion.ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                    objModel.AddToINSTALACION(objInstalacion)
                Else
                    Dim oInst As New INSTALACION()
                    oInst = (From p In objModel.INSTALACION Where p.ID_INSTALACION = objInstalacion.ID_INSTALACION Select p).FirstOrDefault
                    With oInst
                        .DS_TITULO = objInstalacion.DS_TITULO
                        .DS_INSTALACION = objInstalacion.DS_INSTALACION
                        .DS_USUMOD = objInstalacion.DS_USUMOD
                        .DT_FECBAJA = objInstalacion.DT_FECBAJA
                        .OB_IMAGEN = objInstalacion.OB_IMAGEN
                        .ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                    End With
                End If
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_INSTALACION">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Instalacion encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_INSTALACION As Integer) As INSTALACION
            Try
                Return (From p In objModel.INSTALACION Where p.ID_INSTALACION = iD_INSTALACION Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <param name="iD_CENTRO">Id del centro a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Instalacion encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String, ByVal iD_CENTRO As Integer) As List(Of INSTALACION)
            Try
                Return (From p In objModel.INSTALACION Where (p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty) _
                                    And (p.CENTRO.ID_CENTRO = iD_CENTRO Or iD_CENTRO = 0) Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace