Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorOferta

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objOferta">Objeto Oferta que contiene los datos a guardar</param>
        ''' <param name="iD_CENTRO">Id del centro al que pertenece la oferta</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objOferta As Oferta, ByVal iD_CENTRO As Integer)
            Try
                Dim objCtrlCentro As New Controlador.ControladorCentro
                If objOferta.ID_OFERTA.ToString.Equals("0") Then
                    objOferta.ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                    objModel.AddToOFERTA(objOferta)
                Else
                    Dim oOferta As New OFERTA()
                    oOferta = LoadByPK(objOferta.ID_OFERTA)
                    With oOferta
                        .DS_TITULO = objOferta.DS_TITULO
                        .DS_OFERTA = objOferta.DS_OFERTA
                        .DS_USUMOD = objOferta.DS_USUMOD
                        .DT_FECBAJA = objOferta.DT_FECBAJA
                        .ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                    End With
                End If
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_OFERTA">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Oferta encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_OFERTA As Integer) As OFERTA
            Try
                Return (From p In objModel.OFERTA Where p.ID_OFERTA = iD_OFERTA Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <param name="iD_CENTRO">Id del centro a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Oferta encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String, ByVal iD_CENTRO As Integer) As List(Of OFERTA)
            Try
                Return (From p In objModel.OFERTA Where (p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty) _
                                And (p.CENTRO.ID_CENTRO = iD_CENTRO Or iD_CENTRO = 0) Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace