Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorPatrocinador

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private db As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objPatrocinador">Objeto Patrocinador que contiene los datos a guardar</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objPatrocinador As Patrocinador)
            Try
                If objPatrocinador.ID_PATROCINADOR.ToString.Equals("0") Then
                    db.AddToPATROCINADOR(objPatrocinador)
                Else
                    Dim oPatro As New Patrocinador()
                    oPatro = LoadByPK(objPatrocinador.ID_PATROCINADOR)
                    With oPatro
                        .DS_TITULO = objPatrocinador.DS_TITULO
                        .DS_PATROCINADOR = objPatrocinador.DS_PATROCINADOR
                        .DS_USUMOD = objPatrocinador.DS_USUMOD
                        .DT_FECBAJA = objPatrocinador.DT_FECBAJA
                        .OB_LOGOTIPO = objPatrocinador.OB_LOGOTIPO
                    End With
                End If
                db.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_PATROCINADOR">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Patrocinador encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_PATROCINADOR As Integer) As Patrocinador
            Try
                Return (From p In db.PATROCINADOR Where p.ID_PATROCINADOR = iD_PATROCINADOR Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Patrocinador encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String) As List(Of PATROCINADOR)
            Try
                Return (From p In db.PATROCINADOR Where p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de patrocinadores asociados a una competición
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <param name="idComp">Competición a filtrar</param>
        ''' <returns>
        ''' Lista de objetos VW_PATROCINADOR_COMPETICION encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilterCompAsoc(ByVal dS_TITULO As String, ByVal idComp As Integer) As List(Of VW_PATROCINADOR_COMPETICION)
            Try
                Return (From p In db.VW_PATROCINADOR_COMPETICION Where (p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty) AndAlso p.ID_COMPETICION = idComp Select p Order By p.DS_PATROCINADOR).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de patrocinadores no asociados a una competición
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <param name="idComp">Competición a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Patrocinador encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilterCompNoAsoc(ByVal dS_TITULO As String, ByVal idComp As Integer) As List(Of PATROCINADOR)
            Try
                Return db.IMP_PA_GET_PATRO_NO_ASOC(idComp, dS_TITULO).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace