Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorPremio

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objPremio">Objeto Premio que contiene los datos a guardar</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objPremio As Premio)
            Try
                If objPremio.ID_PREMIO.ToString.Equals("0") Then
                    objModel.AddToPREMIO(objPremio)
                Else
                    Dim oPremio As New Premio()
                    oPremio = LoadByPK(objPremio.ID_PREMIO)
                    With oPremio
                        .DS_TITULO = objPremio.DS_TITULO
                        .DS_PREMIO = objPremio.DS_PREMIO
                        .DS_USUMOD = objPremio.DS_USUMOD
                        .DT_FECHA = objPremio.DT_FECHA
                        .OB_PREMIO = objPremio.OB_PREMIO
                    End With
                End If
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_PREMIO">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Premio encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_PREMIO As Integer) As Premio
            Try
                Return (From p In objModel.PREMIO Where p.ID_PREMIO = iD_PREMIO Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="dS_TITULO">Titulo a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Premio encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal dS_TITULO As String) As List(Of PREMIO)
            Try
                Return (From p In objModel.PREMIO Where p.DS_TITULO.Contains(dS_TITULO) Or dS_TITULO = String.Empty Select p Order By p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace