Namespace Controlador

    ''' <summary>
    ''' Clase que contiene los métodos que acceden a la base de datos para obtener crear y modificar registros
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Public Class ControladorUsuario

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private objModel As New dbConnection

        ''' <summary>
        ''' Método que realiza el guardado de un registro
        ''' </summary>
        ''' <param name="objUsuario">Objeto Usuario que contiene los datos a guardar</param>
        ''' <param name="iD_CENTRO">Id del centro al que pertenece el usuario</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub Guardar(ByVal objUsuario As USUARIO, ByVal iD_CENTRO As Integer)
            Try
                Dim objCtrlCentro As New Controlador.ControladorCentro
                If objUsuario.ID_USUARIO.ToString.Equals("0") Then
                    objUsuario.ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                    objModel.AddToUSUARIO(objUsuario)
                Else
                    Dim oUsu As New USUARIO()
                    oUsu = LoadByPK(objUsuario.ID_USUARIO)
                    With oUsu
                        .DS_NOMBRE = objUsuario.DS_NOMBRE
                        .DS_APELLIDO1 = objUsuario.DS_APELLIDO1
                        .DS_APELLIDO2 = objUsuario.DS_APELLIDO2
                        .DS_LOGIN = objUsuario.DS_LOGIN
                        If Not String.IsNullOrWhiteSpace(objUsuario.DS_PASSWORD) Then
                            .DS_PASSWORD = objUsuario.DS_PASSWORD
                        End If
                        .EN_EDAD = objUsuario.EN_EDAD
                        .DS_EMAIL = objUsuario.DS_EMAIL
                        .CH_SEXO = objUsuario.CH_SEXO
                        .DS_USUMOD = objUsuario.DS_USUMOD
                        .DT_FECBAJA = objUsuario.DT_FECBAJA
                        If iD_CENTRO <> 0 Then
                            .ID_CENTRO = CInt(objCtrlCentro.LoadByPK(iD_CENTRO).EntityKey.EntityKeyValues(0).Value)
                        Else
                            .ID_CENTRO = Nothing
                        End If
                    End With
                End If
                objModel.SaveChanges()
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su primary key
        ''' </summary>
        ''' <param name="iD_USUARIO">Id que forma la clave primaria a filtrar</param>
        ''' <returns>
        ''' Objeto Usuario encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByPK(ByVal iD_USUARIO As Integer) As Usuario
            Try
                Return (From p In objModel.USUARIO Where p.ID_USUARIO = iD_USUARIO Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de registros filtrando por el título
        ''' </summary>
        ''' <param name="iD_CENTRO">Id del centro a filtrar</param>
        ''' <param name="dS_NOMBRE">Nombre del usuario a filtrar</param>
        ''' <param name="dS_APELLIDO1">Primer apellido del usuario a filtrar</param>
        ''' <param name="dS_APELLIDO2">Segundo apellido del usuario a filtrar</param>
        ''' <returns>
        ''' Lista de objetos Usuario encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByFilter(ByVal iD_CENTRO As Integer, ByVal dS_NOMBRE As String, ByVal dS_APELLIDO1 As String, ByVal dS_APELLIDO2 As String) As List(Of USUARIO)
            Try
                Return (From p In objModel.USUARIO Where (p.DS_NOMBRE.Contains(dS_NOMBRE) Or dS_NOMBRE = String.Empty) _
                                And (p.DS_APELLIDO1.Contains(dS_APELLIDO1) Or dS_APELLIDO1 = String.Empty) _
                                And (p.DS_APELLIDO2.Contains(dS_APELLIDO2) Or dS_APELLIDO2 = String.Empty) _
                                And (p.CENTRO.ID_CENTRO = iD_CENTRO Or iD_CENTRO = 0) Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la validación de coincidencia de un usuario y contraseña y si está activo el usuario
        ''' </summary>
        ''' <param name="strLogin">Cadena con el nombre de usuario a comprobar</param>
        ''' <param name="strPass">Cadena con la contraseña del usuario a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si el login es válido (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function ValidarUsuario(ByVal strLogin As String, ByVal strPass As String) As USUARIO
            Dim md5Pass As String = Utilidad.Encriptar(strPass)
            Return (From p In objModel.USUARIO Where p.DS_LOGIN = strLogin And p.DS_PASSWORD = md5Pass And p.ID_CENTRO IsNot Nothing And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > Date.Now) Select p).FirstOrDefault
        End Function

        ''' <summary>
        ''' Método que realiza la validación de si existe un nombre de usuario
        ''' </summary>
        ''' <param name="strLogin">Cadena con el nombre de usuario a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si el login existe (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function ValidarLogin(ByVal strLogin As String) As Boolean
            Dim objUsu As USUARIO = (From p In objModel.USUARIO Where p.DS_LOGIN = strLogin Select p).FirstOrDefault
            If objUsu Is Nothing Then
                Return True
            Else
                Return False
            End If
        End Function

        ''' <summary>
        ''' Método que realiza la carga de un combobox con usuarios
        ''' </summary>
        ''' <param name="comboUsuarios">Combobox a cargar</param>
        ''' <param name="boActivos">Indicador para filtrar por activos (True) o desactivos (False)</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Sub CargarCBUsuarios(ByVal comboUsuarios As Controls.ComboBox, ByVal boActivos As Boolean)
            Try
                Dim lUsuarios As List(Of USUARIO)
                If boActivos Then
                    lUsuarios = LoadActivos()
                Else
                    lUsuarios = objModel.USUARIO.ToList
                End If
                Dim item As New USUARIO
                item.ID_USUARIO = 0
                item.DS_LOGIN = MensajeResource("msg_seleccione_usuario")
                lUsuarios.Insert(0, item)
                comboUsuarios.DisplayMemberPath = "DS_LOGIN"
                comboUsuarios.SelectedValuePath = "ID_USUARIO"
                comboUsuarios.ItemsSource = lUsuarios
                comboUsuarios.SelectedIndex = 0
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga de registros activos
        ''' </summary>
        ''' <returns>
        ''' Lista de objetos Usuario encontrados
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadActivos() As List(Of USUARIO)
            Try
                Return (From p In objModel.USUARIO Where (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p Order By p.DS_NOMBRE Ascending, p.DS_APELLIDO1 Ascending, p.DS_APELLIDO2 Ascending).ToList
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza la carga de un registro filtrando por su nombre de usuario
        ''' </summary>
        ''' <param name="dS_LOGIN">Cadena con el nombre de usuario a filtrar</param>
        ''' <returns>
        ''' Objeto Usuario encontrado
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LoadByLogin(ByVal dS_LOGIN As String) As USUARIO
            Try
                Return (From p In objModel.USUARIO Where p.DS_LOGIN = dS_LOGIN Select p).FirstOrDefault
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace