Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.Windows.Controls

Namespace UI.Centros

    ''' <summary>
    ''' Pantalla de modificación de un centro 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class ModificarCentroUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del centro asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_CENTRO As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador del centro así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_CENTRO As Integer)
            _iD_CENTRO = iD_CENTRO
            InitializeComponent()
        End Sub

#Region "Propiedades"

        Public Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
            Set(ByVal value As String)
                txtNombre.Text = value
            End Set
        End Property

        Public Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
            Set(ByVal value As String)
                txtDescripcion.Text = value
            End Set
        End Property

        Public Property Direccion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDireccion.Text) Then
                    Validacion.MarcarCampos(lblDireccion, txtDireccion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDireccion, txtDireccion)
                    Return txtDireccion.Text
                End If
            End Get
            Set(ByVal value As String)
                txtDireccion.Text = value
            End Set
        End Property

        Public Property Telefono() As String
            Get
                If String.IsNullOrWhiteSpace(txtTelefono.Text) Then
                    Validacion.MarcarCampos(lblTelefono, txtTelefono)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblTelefono, txtTelefono)
                    Return txtTelefono.Text
                End If
            End Get
            Set(ByVal value As String)
                txtTelefono.Text = value
            End Set
        End Property

        Public Property Correo() As String
            Get
                If String.IsNullOrWhiteSpace(txtCorreo.Text) Then
                    Validacion.MarcarCampos(lblCorreo, txtCorreo)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCorreo, txtCorreo)
                    Return txtCorreo.Text
                End If
            End Get
            Set(ByVal value As String)
                txtCorreo.Text = value
            End Set
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

#End Region

        ''' <summary>
        ''' Método que realiza la carga del centro a modificar
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub CargarRegistro()
            Try
                Dim objCtrlCentro As New ControladorCentro
                Dim objCentro As New CENTRO
                objCentro = objCtrlCentro.LoadByPK(_iD_CENTRO)
                With objCentro
                    Nombre = .DS_TITULO
                    Descripcion = .DS_CENTRO
                    Direccion = .DS_DIRECCION
                    Telefono = .DS_TELEFONO
                    Correo = .DS_EMAIL
                    FecBaja = .DT_FECBAJA
                    If Not (.GO_LATITUD Is Nothing Or .GO_LONGITUD Is Nothing) Then
                        hdLatitud.Content = .GO_LATITUD
                        hdLongitud.Content = .GO_LONGITUD
                        imgUbicacion.Source = Google.ShowMapUsingLatLng(.GO_LATITUD, .GO_LONGITUD)
                    End If
                End With
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                If Validacion.Correo(Correo) And Validacion.Telefono(Telefono) Then
                    Dim ctrlCentro As New ControladorCentro
                    Dim objCentro As New CENTRO
                    With objCentro
                        .ID_CENTRO = _iD_CENTRO
                        .DS_TITULO = Nombre
                        .DS_CENTRO = Descripcion
                        .DS_DIRECCION = Direccion
                        .DS_TELEFONO = Telefono
                        .DS_EMAIL = Correo
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                        .DT_FECBAJA = FecBaja
                        If hdLatitud.Content Is Nothing Then
                            .GO_LATITUD = Nothing
                            .GO_LONGITUD = Nothing
                        Else
                            .GO_LATITUD = hdLatitud.Content.ToString
                            .GO_LONGITUD = hdLongitud.Content.ToString
                        End If
                    End With
                    If ctrlCentro.Guardar(objCentro) Then
                        MensajeInfo("msg_guardado_ok")
                    End If
                End If
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub ModificarCentroUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                CargarRegistro()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub txtTelefono_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles txtTelefono.KeyDown
            Validacion.SoloNumeros(e)
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnUbicacion_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnUbicacion.Click
            Try
                Dim sms As String
                Dim localizacion As String = txtDireccion.Text.Replace(" ", "+")
                Dim lat As String = String.Empty
                Dim longi As String = String.Empty

                If Not hdLatitud.Content Is Nothing Then
                    lat = hdLatitud.Content.ToString
                    longi = hdLongitud.Content.ToString
                End If

                sms = Google.GetLatLng(localizacion, lat, longi)
                txtDireccion.Text = localizacion
                If Not sms.Equals(String.Empty) Then
                    imgUbicacion.Source = Nothing
                    hdLatitud.Content = Nothing
                    hdLongitud.Content = Nothing
                    MensajeInfo(sms)
                Else
                    hdLatitud.Content = lat
                    hdLongitud.Content = longi
                    imgUbicacion.Source = Google.ShowMapUsingLocation(txtDireccion.Text.Replace(" ", "+"))
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

#End Region

    End Class

End Namespace