Imports Maraton.Admin.UI.Patrocinadores
Imports Maraton.Admin.Controlador
Imports System.Windows.Controls

Namespace UI.Competiciones

    ''' <summary>
    ''' Pantalla de modificación de la relación entre patrocinadores de una competición 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class EditarCompPatroUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador de la competición asociada a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_COMPETICION As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador de la competición así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_COMPETICION As Integer)
            _iD_COMPETICION = iD_COMPETICION
            InitializeComponent()
        End Sub

#Region "Procedimientos"

        ''' <summary>
        ''' Método que realiza la carga del grid de patrocinadores relacionados con la competición
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub BindGridRel()
            Try
                Dim ctrlPatro As New ControladorPatrocinador
                gdDatosRel.ItemsSource = ctrlPatro.LoadByFilterCompAsoc(txtNombreRel.Text, _iD_COMPETICION)
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que realiza la carga del grid de patrocinadores no relacionados con la competición
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub BindGridnoRel()
            Try
                Dim ctrlPatro As New ControladorPatrocinador
                gdDatosNoRel.ItemsSource = ctrlPatro.LoadByFilterCompNoAsoc(txtNombreNoRel.Text, _iD_COMPETICION)
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#End Region

#Region "Eventos"

        Private Sub ConsultarPatrocinadoresUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                Dim ctrl As New ControladorCompeticion
                lblCompeticion.Content = ctrl.LoadByPK(_iD_COMPETICION).DS_TITULO
                BindGridRel()
                BindGridnoRel()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub txtNombreRel_TextChanged(ByVal sender As Object, ByVal e As System.Windows.Controls.TextChangedEventArgs) Handles txtNombreRel.TextChanged
            Try
                BindGridRel()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub txtNombreNoRel_TextChanged(ByVal sender As Object, ByVal e As System.Windows.Controls.TextChangedEventArgs) Handles txtNombreNoRel.TextChanged
            Try
                BindGridnoRel()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVincular_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVincular.Click
            Try
                If gdDatosNoRel.SelectedItems.Count <> 1 Then
                    MensajeWarn("msg_grid_seleccioneRegistro")
                Else
                    Dim iD_PATROCINADOR As Integer = CType(gdDatosNoRel.SelectedItem, PATROCINADOR).ID_PATROCINADOR
                    Dim ctrlCompPatr As New ControladorPatrocinadorCompeticion
                    ctrlCompPatr.Guardar(_iD_COMPETICION, iD_PATROCINADOR)
                    BindGridnoRel()
                    BindGridRel()
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnDesvincular_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnDesvincular.Click
            Try
                If gdDatosRel.SelectedItems.Count <> 1 Then
                    MensajeWarn("msg_grid_seleccioneRegistro")
                Else
                    Dim iD_PATROCINADOR As Integer = CType(gdDatosRel.SelectedItem, VW_PATROCINADOR_COMPETICION).ID_PATROCINADOR
                    Dim ctrlCompPatr As New ControladorPatrocinadorCompeticion
                    ctrlCompPatr.Borrar(_iD_COMPETICION, iD_PATROCINADOR)
                    BindGridnoRel()
                    BindGridRel()
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub gdDatosRel_MouseDoubleClick(ByVal sender As Object, ByVal e As System.Windows.Input.MouseButtonEventArgs) Handles gdDatosRel.MouseDoubleClick
            Try
                If gdDatosRel.SelectedItems.Count <> 1 Then
                    MensajeWarn("msg_grid_seleccioneRegistro")
                Else
                    Dim iD_PATROCINADOR As Integer = CType(gdDatosRel.SelectedItem, VW_PATROCINADOR_COMPETICION).ID_PATROCINADOR
                    Dim ctrlCompPatr As New ControladorPatrocinadorCompeticion
                    ctrlCompPatr.Borrar(_iD_COMPETICION, iD_PATROCINADOR)
                    BindGridnoRel()
                    BindGridRel()
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub gdDatosNoRel_MouseDoubleClick(ByVal sender As Object, ByVal e As System.Windows.Input.MouseButtonEventArgs) Handles gdDatosNoRel.MouseDoubleClick
            Try
                If gdDatosNoRel.SelectedItems.Count <> 1 Then
                    MensajeWarn("msg_grid_seleccioneRegistro")
                Else
                    Dim iD_PATROCINADOR As Integer = CType(gdDatosNoRel.SelectedItem, PATROCINADOR).ID_PATROCINADOR
                    Dim ctrlCompPatr As New ControladorPatrocinadorCompeticion
                    ctrlCompPatr.Guardar(_iD_COMPETICION, iD_PATROCINADOR)
                    BindGridnoRel()
                    BindGridRel()
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

#End Region

    End Class

End Namespace