Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.Windows.Controls
Imports System.IO
Imports System.Text
Imports System.Xml
Imports System.Reflection

Namespace UI.Competiciones

    ''' <summary>
    ''' Pantalla de modificación de una competición 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class ModificarCompeticionUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador de la competición asociada a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_COMPETICION As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador de la competición así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_COMPETICION As Integer)
            _iD_COMPETICION = iD_COMPETICION
            InitializeComponent()
        End Sub

#Region "Propiedades"

        Public Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
            Set(ByVal value As String)
                txtNombre.Text = value
            End Set
        End Property

        Public Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
            Set(ByVal value As String)
                txtDescripcion.Text = value
            End Set
        End Property

        Public Property Fecha() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecha.Text) Then
                    Validacion.MarcarCampos(lblFecha, dpFecha)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblFecha, dpFecha)
                    Return CDate(dpFecha.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecha.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecha.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

#End Region

        ''' <summary>
        ''' Método que realiza la carga de la competición a modificar
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub CargarRegistro()
            Try
                Dim objCtrlCompeticion As New ControladorCompeticion
                Dim objCompeticion As New COMPETICION
                objCompeticion = objCtrlCompeticion.LoadByPK(_iD_COMPETICION)
                With objCompeticion
                    Nombre = .DS_TITULO
                    Descripcion = .DS_COMPETICION
                    Fecha = .DT_FECHA
                    If Not .OB_RECORRIDO Is Nothing Then
                        hdXML.Content = .OB_RECORRIDO
                        txtRecorrido.Text = MensajeResource("msg_recorrido_cargado")
                        'Dim fName = AppDomain.CurrentDomain.BaseDirectory & .ID_COMPETICION.ToString & ".kml"
                        'Dim objWriter As New StreamWriter(fName)
                        'objWriter.Write(.OB_RECORRIDO)
                        'objWriter.Close()

                        'Dim contenido As String = File.ReadAllText("../../UI/Maps.html")
                        'contenido = contenido.Replace("[fichero]", fName.Replace("\", "/"))
                        'wbContent.NavigateToString(contenido)

                    'Else
                        'wbContent.Visibility = Visibility.Hidden
                    End If
                End With
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlCompeticion As New ControladorCompeticion
                Dim objComp As New COMPETICION
                With objComp
                    .ID_COMPETICION = _iD_COMPETICION
                    .DS_TITULO = Nombre
                    .DS_COMPETICION = Descripcion
                    .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    .DT_FECHA = Fecha.Value

                    If Not String.IsNullOrWhiteSpace(txtRecorrido.Text) AndAlso Not txtRecorrido.Text.Equals(MensajeResource("msg_recorrido_cargado")) Then
                        Dim b As BinaryReader = New BinaryReader(File.Open(txtRecorrido.Text, FileMode.Open))
                        Dim binData As Byte() = b.ReadBytes(CInt(b.BaseStream.Length))
                        b.Close()
                        Dim fichero As String = Encoding.UTF8.GetString(binData)
                        If fichero.StartsWith("<?xml") Then
                            fichero = fichero.Remove(0, fichero.IndexOf(">") + 1)
                        End If
                        .OB_RECORRIDO = fichero
                    ElseIf hdXML.Content Is Nothing Then
                        .OB_RECORRIDO = Nothing
                    Else
                        .OB_RECORRIDO = hdXML.Content.ToString
                    End If

                End With
                ctrlCompeticion.Guardar(objComp)
                MensajeInfo("msg_guardado_ok")
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnRecorrido_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnRecorrido.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                dialog.Title = TITULO_DIALOG_GPS
                dialog.Filter = EXTENSIONES_GPS
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        hdXML.Content = Nothing
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        hdXML.Content = "OK"
                        txtRecorrido.Text = dialog.FileName

                        'Dim fName = AppDomain.CurrentDomain.BaseDirectory & _iD_COMPETICION.ToString & ".kml"
                        'Dim objWriter As New StreamWriter(fName)

                        'Dim b As BinaryReader = New BinaryReader(File.Open(txtRecorrido.Text, FileMode.Open))
                        'Dim binData As Byte() = b.ReadBytes(CInt(b.BaseStream.Length))
                        'b.Close()
                        'Dim fichero As String = Encoding.UTF8.GetString(binData)
                        'If fichero.StartsWith("<?xml") Then
                        '    fichero = fichero.Remove(0, fichero.IndexOf(">") + 1)
                        'End If

                        'objWriter.Write(fichero)
                        'objWriter.Close()

                        'Dim contenido As String = File.ReadAllText("../../UI/Maps.html")
                        'contenido = contenido.Replace("[fichero]", fName.Replace("\", "/"))
                        'wbContent.NavigateToString(contenido)

                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub ModificarCompeticionUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                'wbContent.Visibility = Windows.Visibility.Hidden
                CargarRegistro()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnPatrocinador_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnPatrocinador.Click
            Try
                CType(Application.Current.MainWindow, Main).contenido.Navigate(New EditarCompPatroUI(_iD_COMPETICION))
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnQuitarRecorrido_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarRecorrido.Click
            Try
                hdXML.Content = Nothing
                txtRecorrido.Text = String.Empty
                'wbContent.Visibility = Visibility.Hidden
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        'Private Sub wbContent_Navigated(ByVal sender As Object, ByVal e As System.Windows.Navigation.NavigationEventArgs) Handles wbContent.Navigated
            'Dim fiComWebBrowser As FieldInfo = GetType(WebBrowser).GetField("_axIWebBrowser2", BindingFlags.Instance Or BindingFlags.NonPublic)
            'If fiComWebBrowser Is Nothing Then
                'Return
            'End If
            'Dim objComWebBrowser As Object = fiComWebBrowser.GetValue(wbContent)
            'If objComWebBrowser Is Nothing Then
                'Return
            'End If
            'objComWebBrowser.[GetType]().InvokeMember("Silent", BindingFlags.SetProperty, Nothing, objComWebBrowser, New Object() {True})
        'End Sub

#End Region

    End Class

End Namespace