Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.IO
Imports System.Windows.Controls

Namespace UI.Instalaciones

    ''' <summary>
    ''' Pantalla de creación de una instalación
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class CrearInstalacionUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador de la instalación asociada a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_INSTALACION As Integer

#Region "Propiedades"

        Public ReadOnly Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

        Public ReadOnly Property Centro() As Integer
            Get
                If cbCentro.SelectedValue.Equals(0) Then
                    Validacion.MarcarCampos(lblCentro, cbCentro)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCentro, cbCentro)
                    Return CInt(cbCentro.SelectedValue)
                End If
            End Get
        End Property

#End Region

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlInstalacion As New ControladorInstalacion
                Dim objInst As New INSTALACION
                With objInst
                    .DS_TITULO = Nombre
                    .DS_INSTALACION = Descripcion
                    If _iD_INSTALACION = 0 Then
                        .DS_USUALTA = Utilidad.GetSession().DS_LOGIN
                    Else
                        .ID_INSTALACION = _iD_INSTALACION
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    End If
                    .DT_FECBAJA = FecBaja

                    If Not imgInstalacion.Source Is Nothing Then
                        Dim fs As New FileStream(txtInstalacion.Text, FileMode.Open, FileAccess.Read)
                        Dim data(CInt(fs.Length)) As Byte
                        fs.Read(data, 0, System.Convert.ToInt32(fs.Length))
                        fs.Close()
                        .OB_IMAGEN = data
                    End If

                End With
                ctrlInstalacion.Guardar(objInst, Centro)
                MensajeInfo("msg_guardado_ok")
                _iD_INSTALACION = objInst.ID_INSTALACION
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnInstalacion_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnInstalacion.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                Dim bmImage As New BitmapImage
                dialog.Title = TITULO_DIALOG_IMG
                dialog.Filter = EXTENSIONES_IMG
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        bmImage.BeginInit()
                        bmImage.UriSource = New Uri(dialog.FileName)
                        bmImage.EndInit()
                        imgInstalacion.Stretch = Stretch.Fill
                        imgInstalacion.Source = bmImage
                        txtInstalacion.Text = dialog.FileName
                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub CrearInstalacionUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                _iD_INSTALACION = 0
                Dim objCtrlCentros As New Controlador.ControladorCentro
                objCtrlCentros.CargarCBCentros(cbCentro, True)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnQuitarInstalacion_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarInstalacion.Click
            Try
                txtInstalacion.Text = String.Empty
                imgInstalacion.Source = Nothing
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

#End Region

    End Class

End Namespace