Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.IO
Imports System.Windows.Controls

Namespace UI.Instalaciones

    ''' <summary>
    ''' Pantalla de modificación de una instalación 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class ModificarInstalacionUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador de la instalación asociada a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_INSTALACION As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador de la instalación así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_INSTALACION As Integer)
            _iD_INSTALACION = iD_INSTALACION
            InitializeComponent()
        End Sub

#Region "Propiedades"

        Public Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
            Set(ByVal value As String)
                txtNombre.Text = value
            End Set
        End Property

        Public Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
            Set(ByVal value As String)
                txtDescripcion.Text = value
            End Set
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

        Public Property Centro() As Integer
            Get
                If cbCentro.SelectedValue.Equals(0) Then
                    Validacion.MarcarCampos(lblCentro, cbCentro)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCentro, cbCentro)
                    Return CInt(cbCentro.SelectedValue)
                End If
            End Get
            Set(ByVal value As Integer)
                cbCentro.SelectedValue = value
            End Set
        End Property

#End Region

        ''' <summary>
        ''' Método que realiza la carga de la instalación a modificar
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub CargarRegistro()
            Try
                Dim objCtrlInstalacion As New ControladorInstalacion
                Dim objInstalacion As New INSTALACION
                objInstalacion = objCtrlInstalacion.LoadByPK(_iD_INSTALACION)
                With objInstalacion
                    Nombre = .DS_TITULO
                    Descripcion = .DS_INSTALACION
                    FecBaja = .DT_FECBAJA

                    For Each cbItem As CENTRO In cbCentro.Items
                        If cbItem.ID_CENTRO = .CENTROReference.Value.ID_CENTRO Then
                            Centro = .CENTROReference.Value.ID_CENTRO
                            Exit For
                        End If
                    Next

                    If Not .OB_IMAGEN Is Nothing Then
                        Dim data As Byte() = CType(.OB_IMAGEN, Byte())
                        Dim strm As New MemoryStream()
                        strm.Write(data, 0, data.Length)
                        strm.Position = 0
                        Dim img As System.Drawing.Image = System.Drawing.Image.FromStream(strm)
                        Dim bi As New BitmapImage
                        bi.BeginInit()
                        Dim ms As New MemoryStream
                        img.Save(ms, System.Drawing.Imaging.ImageFormat.Bmp)
                        ms.Seek(0, SeekOrigin.Begin)
                        bi.StreamSource = ms
                        bi.EndInit()
                        imgInstalacion.Source = bi
                    End If
                End With
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlInstalacion As New ControladorInstalacion
                Dim objInst As New INSTALACION
                With objInst
                    .ID_INSTALACION = _iD_INSTALACION
                    .DS_TITULO = Nombre
                    .DS_INSTALACION = Descripcion
                    .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    .DT_FECBAJA = FecBaja

                    If String.IsNullOrWhiteSpace(txtInstalacion.Text) Then
                        .OB_IMAGEN = Nothing
                    Else
                        Dim fs As New FileStream(txtInstalacion.Text, FileMode.Open, FileAccess.Read)
                        Dim data(CInt(fs.Length)) As Byte
                        fs.Read(data, 0, System.Convert.ToInt32(fs.Length))
                        fs.Close()
                        .OB_IMAGEN = data
                    End If

                End With
                ctrlInstalacion.Guardar(objInst, Centro)
                MensajeInfo("msg_guardado_ok")
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub ModificarInstalacionUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                Dim objCtrlCentros As New Controlador.ControladorCentro
                objCtrlCentros.CargarCBCentros(cbCentro, True)
                CargarRegistro()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnInstalacion_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnInstalacion.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                Dim bmImage As New BitmapImage
                dialog.Title = TITULO_DIALOG_IMG
                dialog.Filter = EXTENSIONES_IMG
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        bmImage.BeginInit()
                        bmImage.UriSource = New Uri(dialog.FileName)
                        bmImage.EndInit()
                        imgInstalacion.Stretch = Stretch.Fill
                        imgInstalacion.Source = bmImage
                        txtInstalacion.Text = dialog.FileName
                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnQuitarInstalacion_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarInstalacion.Click
            Try
                txtInstalacion.Text = String.Empty
                imgInstalacion.Source = Nothing
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

#End Region

    End Class

End Namespace