Imports Maraton.Admin.UTIL.Mensaje
Imports Maraton.Admin.Exceptions
Imports Maraton.Admin.UTIL.Log
Imports System.Threading

Namespace UI

    ''' <summary>
    ''' Pantalla de login para acceder a la aplicación. 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Class Login

#Region "Propiedades"

        Public ReadOnly Property Login() As String
            Get
                If String.IsNullOrWhiteSpace(txtLogin.Text) Then
                    Validacion.MarcarCampos(lblLogin, txtLogin)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblLogin, txtLogin)
                    Return txtLogin.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Password() As String
            Get
                If String.IsNullOrWhiteSpace(txtPassword.Password) Then
                    Validacion.MarcarCampos(lblPassword, txtPassword)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblPassword, txtPassword)
                    Return txtPassword.Password
                End If
            End Get
        End Property

#End Region

#Region "Eventos"

        Private Sub btnAceptar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnAceptar.Click
            Try
                Dim objCtrlUsu As New Controlador.ControladorUsuario
                Dim objUsu As New USUARIO
                objUsu = objCtrlUsu.ValidarUsuario(Login, Password)
                If objUsu Is Nothing Then
                    MensajeError("msg_login_error")
                    LogWarn("log_usuario_intento", "%1", Login)
                Else
                    Application.Current.Properties.Add("usuario", objUsu)
                    Dim frmMain As New Main
                    frmMain.Activate()
                    frmMain.Show()
                    Me.Close()
                    LogInfo("log_usuario_acceso", "%1", Login)
                End If
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub Login_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            txtLogin.Focus()
            SetLanguageDictionary()
        End Sub

        Private Sub btnCancelar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnCancelar.Click
            Application.Current.Shutdown()
        End Sub

#End Region

        ''' <summary>
        ''' Método que establece el idioma en función de la configuración local del equipo
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado amorgadoc@uoc.edu 10/04/2013
        ''' </remarks>
        Private Sub SetLanguageDictionary()
            Try
                Dim dict As New ResourceDictionary()
                Select Case Thread.CurrentThread.CurrentCulture.ToString()
                    Case "en-GB"
                        dict.Source = New Uri(".\Resources\Messages\mensajes.en-GB.xaml", UriKind.Relative)
                    Case "ca-ES"
                        dict.Source = New Uri(".\Resources\Messages\mensajes.ca-ES.xaml", UriKind.Relative)
                    Case Else
                        dict.Source = New Uri(".\Resources\Messages\mensajes.xaml", UriKind.Relative)
                End Select
                Application.Current.Resources.MergedDictionaries.Add(dict)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub lnkOlvido_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles lnkOlvido.Click
            Dim frmMain As New RecuperarPass
            frmMain.Activate()
            frmMain.Show()
            Me.Close()
        End Sub

    End Class

End Namespace
