Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.Windows.Controls

Namespace UI.Ofertas

    ''' <summary>
    ''' Pantalla de creación de una oferta
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class CrearOfertaUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador de la oferta asociada a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_OFERTA As Integer

#Region "Propiedades"

        Public ReadOnly Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

        Public ReadOnly Property Centro() As Integer
            Get
                If cbCentro.SelectedValue.Equals(0) Then
                    Validacion.MarcarCampos(lblCentro, cbCentro)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCentro, cbCentro)
                    Return CInt(cbCentro.SelectedValue)
                End If
            End Get
        End Property

#End Region

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlOferta As New ControladorOferta
                Dim objOferta As New OFERTA
                With objOferta
                    .DS_TITULO = Nombre
                    .DS_OFERTA = Descripcion
                    If _iD_OFERTA = 0 Then
                        .DS_USUALTA = Utilidad.GetSession().DS_LOGIN
                    Else
                        .ID_OFERTA = _iD_OFERTA
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    End If
                    .DT_FECBAJA = FecBaja
                End With
                ctrlOferta.Guardar(objOferta, Centro)
                MensajeInfo("msg_guardado_ok")
                _iD_OFERTA = objOferta.ID_OFERTA
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub CrearOfertaUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                _iD_OFERTA = 0
                Dim objCtrlCentros As New Controlador.ControladorCentro
                objCtrlCentros.CargarCBCentros(cbCentro, True)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

#End Region

    End Class

End Namespace