Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.IO
Imports System.Windows.Controls

Namespace UI.Patrocinadores

    ''' <summary>
    ''' Pantalla de creación de un patrocinador 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class CrearPatrocinadorUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del patrocinador asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_PATROCINADOR As Integer

#Region "Propiedades"

        Public ReadOnly Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

#End Region

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlPatrocinador As New ControladorPatrocinador
                Dim objPatro As New PATROCINADOR
                With objPatro
                    .DS_TITULO = Nombre
                    .DS_PATROCINADOR = Descripcion
                    If _iD_PATROCINADOR = 0 Then
                        .DS_USUALTA = Utilidad.GetSession().DS_LOGIN
                    Else
                        .ID_PATROCINADOR = _iD_PATROCINADOR
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    End If
                    .DT_FECBAJA = FecBaja

                    If Not imgLogotipo.Source Is Nothing Then
                        Dim fs As New FileStream(txtLogotipo.Text, FileMode.Open, FileAccess.Read)
                        Dim data(CInt(fs.Length)) As Byte
                        fs.Read(data, 0, System.Convert.ToInt32(fs.Length))
                        fs.Close()
                        .OB_LOGOTIPO = data
                    End If

                End With
                ctrlPatrocinador.Guardar(objPatro)
                MensajeInfo("msg_guardado_ok")
                _iD_PATROCINADOR = objPatro.ID_PATROCINADOR
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnLogotipo_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnLogotipo.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                Dim bmImage As New BitmapImage
                dialog.Title = TITULO_DIALOG_IMG
                dialog.Filter = EXTENSIONES_IMG
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        bmImage.BeginInit()
                        bmImage.UriSource = New Uri(dialog.FileName)
                        bmImage.EndInit()
                        imgLogotipo.Stretch = Stretch.Fill
                        imgLogotipo.Source = bmImage
                        txtLogotipo.Text = dialog.FileName
                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnQuitarLogotipo_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarLogotipo.Click
            Try
                txtLogotipo.Text = String.Empty
                imgLogotipo.Source = Nothing
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub CrearPatrocinadorUI_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded
            _iD_PATROCINADOR = 0
        End Sub

#End Region

    End Class

End Namespace