Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.IO
Imports System.Windows.Controls

Namespace UI.Premios

    ''' <summary>
    ''' Pantalla de creación de un premio 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class CrearPremioUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del premio asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_PREMIO As Integer

#Region "Propiedades"

        Public ReadOnly Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
        End Property

        Public Property Fecha() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecha.Text) Then
                    Validacion.MarcarCampos(lblFecha, dpFecha)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblFecha, dpFecha)
                    Return CDate(dpFecha.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecha.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecha.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

#End Region

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlPremio As New ControladorPremio
                Dim objPremio As New PREMIO
                With objPremio
                    .DS_TITULO = Nombre
                    .DS_PREMIO = Descripcion
                    If _iD_PREMIO = 0 Then
                        .DS_USUALTA = Utilidad.GetSession().DS_LOGIN
                    Else
                        .ID_PREMIO = _iD_PREMIO
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    End If
                    .DT_FECHA = Fecha.Value

                    If Not imgPremio.Source Is Nothing Then
                        Dim fs As New FileStream(txtPremio.Text, FileMode.Open, FileAccess.Read)
                        Dim data(CInt(fs.Length)) As Byte
                        fs.Read(data, 0, System.Convert.ToInt32(fs.Length))
                        fs.Close()
                        .OB_PREMIO = data
                    End If

                End With
                ctrlPremio.Guardar(objPremio)
                MensajeInfo("msg_guardado_ok")
                _iD_PREMIO = objPremio.ID_PREMIO
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnPremio_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnPremio.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                Dim bmImage As New BitmapImage
                dialog.Title = TITULO_DIALOG_IMG
                dialog.Filter = EXTENSIONES_IMG
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        bmImage.BeginInit()
                        bmImage.UriSource = New Uri(dialog.FileName)
                        bmImage.EndInit()
                        imgPremio.Stretch = Stretch.Fill
                        imgPremio.Source = bmImage
                        txtPremio.Text = dialog.FileName
                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnQuitarPremio_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarPremio.Click
            Try
                txtPremio.Text = String.Empty
                imgPremio.Source = Nothing
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub CrearPremioUI_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded
            _iD_PREMIO = 0
        End Sub

#End Region

    End Class

End Namespace