Imports Maraton.Admin.UTIL.Utilidad
Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.IO
Imports System.Windows.Controls

Namespace UI.Premios

    ''' <summary>
    ''' Pantalla de modificación de un premio 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class ModificarPremioUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del premio asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_PREMIO As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador del premio así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_PREMIO As Integer)
            _iD_PREMIO = iD_PREMIO
            InitializeComponent()
        End Sub

#Region "Propiedades"

        Public Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
            Set(ByVal value As String)
                txtNombre.Text = value
            End Set
        End Property

        Public Property Descripcion() As String
            Get
                If String.IsNullOrWhiteSpace(txtDescripcion.Text) Then
                    Validacion.MarcarCampos(lblDescripcion, txtDescripcion)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblDescripcion, txtDescripcion)
                    Return txtDescripcion.Text
                End If
            End Get
            Set(ByVal value As String)
                txtDescripcion.Text = value
            End Set
        End Property

        Public Property Fecha() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecha.Text) Then
                    Validacion.MarcarCampos(lblFecha, dpFecha)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblFecha, dpFecha)
                    Return CDate(dpFecha.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecha.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecha.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

#End Region

        ''' <summary>
        ''' Método que realiza la carga del premio a modificar
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub CargarRegistro()
            Try
                Dim objCtrlPremio As New ControladorPremio
                Dim objPremio As New PREMIO
                objPremio = objCtrlPremio.LoadByPK(_iD_PREMIO)
                With objPremio
                    Nombre = .DS_TITULO
                    Descripcion = .DS_PREMIO
                    Fecha = .DT_FECHA
                    If Not .OB_PREMIO Is Nothing Then
                        Dim data As Byte() = CType(.OB_PREMIO, Byte())
                        Dim strm As New MemoryStream()
                        strm.Write(data, 0, data.Length)
                        strm.Position = 0
                        Dim img As System.Drawing.Image = System.Drawing.Image.FromStream(strm)
                        Dim bi As New BitmapImage
                        bi.BeginInit()
                        Dim ms As New MemoryStream
                        img.Save(ms, System.Drawing.Imaging.ImageFormat.Bmp)
                        ms.Seek(0, SeekOrigin.Begin)
                        bi.StreamSource = ms
                        bi.EndInit()
                        imgPremio.Source = bi
                    End If
                End With
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                Dim ctrlPremio As New ControladorPremio
                Dim objPremio As New PREMIO
                With objPremio
                    .ID_PREMIO = _iD_PREMIO
                    .DS_TITULO = Nombre
                    .DS_PREMIO = Descripcion
                    .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                    .DT_FECHA = Fecha.Value

                    If String.IsNullOrWhiteSpace(txtPremio.Text) Then
                        .OB_PREMIO = Nothing
                    Else
                        Dim fs As New FileStream(txtPremio.Text, FileMode.Open, FileAccess.Read)
                        Dim data(CInt(fs.Length)) As Byte
                        fs.Read(data, 0, System.Convert.ToInt32(fs.Length))
                        fs.Close()
                        .OB_PREMIO = data
                    End If

                End With
                ctrlPremio.Guardar(objPremio)
                MensajeInfo("msg_guardado_ok")
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub ModificarPremioUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                CargarRegistro()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnPremio_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnPremio.Click
            Try
                Dim dialog As New Microsoft.Win32.OpenFileDialog
                Dim bmImage As New BitmapImage
                dialog.Title = TITULO_DIALOG_IMG
                dialog.Filter = EXTENSIONES_IMG
                If dialog.ShowDialog Then
                    If (New FileInfo(dialog.FileName).Length > 4194304) Then
                        MensajeWarn("msg_imagen_tamanyo")
                    Else
                        bmImage.BeginInit()
                        bmImage.UriSource = New Uri(dialog.FileName)
                        bmImage.EndInit()
                        imgPremio.Stretch = Stretch.Fill
                        imgPremio.Source = bmImage
                        txtPremio.Text = dialog.FileName
                    End If
                End If
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

        Private Sub btnQuitarPremio_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnQuitarPremio.Click
            Try
                txtPremio.Text = String.Empty
                imgPremio.Source = Nothing
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

#End Region

    End Class

End Namespace