Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.Windows.Controls

Namespace UI.Usuarios

    ''' <summary>
    ''' Pantalla de creación de un usuario 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    Partial Public Class CrearUsuarioUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del usuario asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_USUARIO As Integer

#Region "Propiedades"

        Public ReadOnly Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Apellido1() As String
            Get
                If String.IsNullOrWhiteSpace(txtApellido1.Text) Then
                    Validacion.MarcarCampos(lblApellido1, txtApellido1)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblApellido1, txtApellido1)
                    Return txtApellido1.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Apellido2() As String
            Get
                If String.IsNullOrWhiteSpace(txtApellido2.Text) Then
                    Validacion.MarcarCampos(lblApellido2, txtApellido2)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblApellido2, txtApellido2)
                    Return txtApellido2.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Login() As String
            Get
                If String.IsNullOrWhiteSpace(txtLogin.Text) Then
                    Validacion.MarcarCampos(lblLogin, txtLogin)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblLogin, txtLogin)
                    Return txtLogin.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Password1() As String
            Get
                If String.IsNullOrWhiteSpace(txtPassword1.Password) Then
                    Validacion.MarcarCampos(lblPassword1, txtPassword1)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblPassword1, txtPassword1)
                    Return txtPassword1.Password
                End If
            End Get
        End Property

        Public ReadOnly Property Password2() As String
            Get
                If String.IsNullOrWhiteSpace(txtPassword2.Password) Then
                    Validacion.MarcarCampos(lblPassword2, txtPassword2)
                    Throw New RequiredFieldException()
                ElseIf Not Password1.Equals(txtPassword2.Password) Then
                    Validacion.MarcarCampos(lblPassword1, txtPassword1)
                    Validacion.MarcarCampos(lblPassword2, txtPassword2)
                    Throw New PasswordEqualsException()
                Else
                    Validacion.DesmarcarCampos(lblPassword2, txtPassword2)
                    Return txtPassword2.Password
                End If
            End Get
        End Property

        Public ReadOnly Property Edad() As String
            Get
                If String.IsNullOrWhiteSpace(txtEdad.Text) Then
                    Validacion.MarcarCampos(lblEdad, txtEdad)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblEdad, txtEdad)
                    Return txtEdad.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Correo() As String
            Get
                If String.IsNullOrWhiteSpace(txtCorreo.Text) Then
                    Validacion.MarcarCampos(lblCorreo, txtCorreo)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCorreo, txtCorreo)
                    Return txtCorreo.Text
                End If
            End Get
        End Property

        Public ReadOnly Property Sexo() As String
            Get
                If rbHombre.IsChecked Then
                    Return "H"
                Else
                    Return "M"
                End If
            End Get
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

        Public ReadOnly Property Centro() As Integer
            Get
                If cbCentro.SelectedValue.Equals(0) Then
                    Return 0
                Else
                    Return CInt(cbCentro.SelectedValue)
                End If
            End Get
        End Property

#End Region

#Region "Eventos"

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                If Validacion.Correo(Correo) And Validacion.Edad(Edad) Then
                    Dim ctrlUsuario As New ControladorUsuario
                    If ctrlUsuario.ValidarLogin(Login) Then
                        Dim objUsuario As New USUARIO
                        With objUsuario
                            .DS_NOMBRE = Nombre
                            .DS_APELLIDO1 = Apellido1
                            .DS_APELLIDO2 = Apellido2
                            .DS_LOGIN = Login
                            .DS_PASSWORD = Utilidad.Encriptar(Password2)
                            .EN_EDAD = CInt(Edad)
                            .DS_EMAIL = Correo
                            .CH_SEXO = Sexo
                            If _iD_USUARIO = 0 Then
                                .DS_USUALTA = Utilidad.GetSession().DS_LOGIN
                            Else
                                .ID_USUARIO = _iD_USUARIO
                                .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                            End If
                            .DT_FECBAJA = FecBaja
                        End With
                        ctrlUsuario.Guardar(objUsuario, Centro)
                        MensajeInfo("msg_guardado_ok")
                        _iD_USUARIO = objUsuario.ID_USUARIO
                    Else
                        MensajeError("msg_login_existe")
                    End If
                End If
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch passEx As Exceptions.PasswordEqualsException
                MensajeError(passEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub CrearUsuarioUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                _iD_USUARIO = 0
                Dim objCtrlCentros As New Controlador.ControladorCentro
                objCtrlCentros.CargarCBCentros(cbCentro, True)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub txtEdad_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles txtEdad.KeyDown
            Validacion.SoloNumeros(e)
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

#End Region

    End Class

End Namespace