Imports Maraton.Admin.Controlador
Imports Maraton.Admin.Exceptions
Imports System.Windows.Controls

Namespace UI.Usuarios

    ''' <summary>
    ''' Pantalla de modificación de un usuario 
    ''' Contiene propiedades para acceder a los controles y controlar si son obligatorios
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>  
    Partial Public Class ModificarUsuarioUI

        ''' <summary>
        ''' Atributo privado que contiene el identificador del usuario asociado a los datos de la pantalla
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private _iD_USUARIO As Integer

        ''' <summary>
        ''' Constructor de la clase que inicializa el identificador del usuario así como los componentes
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Sub New(ByVal iD_USUARIO As Integer)
            _iD_USUARIO = iD_USUARIO
            InitializeComponent()
        End Sub

#Region "Propiedades"

        Public Property Nombre() As String
            Get
                If String.IsNullOrWhiteSpace(txtNombre.Text) Then
                    Validacion.MarcarCampos(lblNombre, txtNombre)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblNombre, txtNombre)
                    Return txtNombre.Text
                End If
            End Get
            Set(ByVal value As String)
                txtNombre.Text = value
            End Set
        End Property

        Public Property Apellido1() As String
            Get
                If String.IsNullOrWhiteSpace(txtApellido1.Text) Then
                    Validacion.MarcarCampos(lblApellido1, txtApellido1)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblApellido1, txtApellido1)
                    Return txtApellido1.Text
                End If
            End Get
            Set(ByVal value As String)
                txtApellido1.Text = value
            End Set
        End Property

        Public Property Apellido2() As String
            Get
                If String.IsNullOrWhiteSpace(txtApellido2.Text) Then
                    Validacion.MarcarCampos(lblApellido2, txtApellido2)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblApellido2, txtApellido2)
                    Return txtApellido2.Text
                End If
            End Get
            Set(ByVal value As String)
                txtApellido2.Text = value
            End Set
        End Property

        Public Property Login() As String
            Get
                If String.IsNullOrWhiteSpace(txtLogin.Text) Then
                    Validacion.MarcarCampos(lblLogin, txtLogin)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblLogin, txtLogin)
                    Return txtLogin.Text
                End If
            End Get
            Set(ByVal value As String)
                txtLogin.Text = value
            End Set
        End Property

        Public Property Password1() As String
            Get
                If String.IsNullOrWhiteSpace(txtPassword1.Password) Then
                    Return String.Empty
                Else
                    Validacion.DesmarcarCampos(lblPassword1, txtPassword1)
                    Return txtPassword1.Password
                End If
            End Get
            Set(ByVal value As String)
                txtPassword1.Password = value
            End Set
        End Property

        Public Property Password2() As String
            Get
                If Not Password1.Equals(txtPassword2.Password) Then
                    Validacion.MarcarCampos(lblPassword1, txtPassword1)
                    Validacion.MarcarCampos(lblPassword2, txtPassword2)
                    Throw New PasswordEqualsException()
                Else
                    Validacion.DesmarcarCampos(lblPassword2, txtPassword2)
                    Return txtPassword2.Password
                End If
            End Get
            Set(ByVal value As String)
                txtPassword2.Password = value
            End Set
        End Property

        Public Property Edad() As String
            Get
                If String.IsNullOrWhiteSpace(txtEdad.Text) Then
                    Validacion.MarcarCampos(lblEdad, txtEdad)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblEdad, txtEdad)
                    Return txtEdad.Text
                End If
            End Get
            Set(ByVal value As String)
                txtEdad.Text = value
            End Set
        End Property

        Public Property Correo() As String
            Get
                If String.IsNullOrWhiteSpace(txtCorreo.Text) Then
                    Validacion.MarcarCampos(lblCorreo, txtCorreo)
                    Throw New RequiredFieldException()
                Else
                    Validacion.DesmarcarCampos(lblCorreo, txtCorreo)
                    Return txtCorreo.Text
                End If
            End Get
            Set(ByVal value As String)
                txtCorreo.Text = value
            End Set
        End Property

        Public Property Sexo() As String
            Get
                If rbHombre.IsChecked Then
                    Return "H"
                Else
                    Return "M"
                End If
            End Get
            Set(ByVal value As String)
                If value.Equals("H") Then
                    rbHombre.IsChecked = True
                Else
                    rbMujer.IsChecked = True
                End If
            End Set
        End Property

        Public Property FecBaja() As Date?
            Get
                If String.IsNullOrWhiteSpace(dpFecBaja.Text) Then
                    Return Nothing
                Else
                    Return CDate(dpFecBaja.Text)
                End If
            End Get
            Set(ByVal value As Date?)
                If value Is Nothing Then
                    dpFecBaja.Text = MensajeResource("label_seleccione_fecha")
                Else
                    dpFecBaja.Text = CDate(value).ToShortDateString
                End If
            End Set
        End Property

        Public Property Centro() As Integer
            Get
                If cbCentro.SelectedValue.Equals(0) Then
                    Return 0
                Else
                    Return CInt(cbCentro.SelectedValue)
                End If
            End Get
            Set(ByVal value As Integer)
                cbCentro.SelectedValue = value
            End Set
        End Property

#End Region

        ''' <summary>
        ''' Método que realiza la carga del usuario a modificar
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Sub CargarRegistro()
            Try
                Dim objCtrlUsuario As New ControladorUsuario
                Dim objUsuario As New USUARIO
                objUsuario = objCtrlUsuario.LoadByPK(_iD_USUARIO)
                With objUsuario
                    Nombre = .DS_NOMBRE
                    Apellido1 = .DS_APELLIDO1
                    Apellido2 = .DS_APELLIDO2
                    Login = .DS_LOGIN
                    Edad = .EN_EDAD.ToString
                    Correo = .DS_EMAIL
                    Sexo = .CH_SEXO
                    FecBaja = .DT_FECBAJA

                    If .CENTROReference.Value Is Nothing Then
                        cbCentro.SelectedValue = 0
                    Else
                        For Each cbItem As CENTRO In cbCentro.Items
                            If cbItem.ID_CENTRO = .CENTROReference.Value.ID_CENTRO Then
                                cbCentro.SelectedValue = .CENTROReference.Value.ID_CENTRO
                                Exit For
                            End If
                        Next
                    End If

                End With
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

#Region "Eventos"

        Private Sub ModificarUsuarioUI_Loaded(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Loaded
            Try
                Dim objCtrlCentros As New Controlador.ControladorCentro
                objCtrlCentros.CargarCBCentros(cbCentro, True)
                CargarRegistro()
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub btnGuardar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGuardar.Click
            Try
                If Validacion.Correo(Correo) And Validacion.Edad(Edad) Then
                    Dim ctrlUsuario As New ControladorUsuario
                    Dim objUsuario As New USUARIO
                    With objUsuario
                        .ID_USUARIO = _iD_USUARIO
                        .DS_NOMBRE = Nombre
                        .DS_APELLIDO1 = Apellido1
                        .DS_APELLIDO2 = Apellido2
                        .DS_LOGIN = Login
                        If String.IsNullOrWhiteSpace(Password2) Then
                            .DS_PASSWORD = String.Empty
                        Else
                            .DS_PASSWORD = Utilidad.Encriptar(Password2)
                        End If
                        .EN_EDAD = CInt(Edad)
                        .DS_EMAIL = Correo
                        .CH_SEXO = Sexo
                        .DS_USUMOD = Utilidad.GetSession().DS_LOGIN
                        .DT_FECBAJA = FecBaja
                    End With
                    ctrlUsuario.Guardar(objUsuario, Centro)
                    MensajeInfo("msg_guardado_ok")
                End If
            Catch rVEx As Exceptions.RequiredFieldException
                MensajeError(rVEx.ToString)
            Catch passEx As Exceptions.PasswordEqualsException
                MensajeError(passEx.ToString)
            Catch ex As Exception
                LogError(ex)
            End Try
        End Sub

        Private Sub txtEdad_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles txtEdad.KeyDown
            Validacion.SoloNumeros(e)
        End Sub

        Private Sub btnVolver_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnVolver.Click
            Dim marco As Frame = CType(Application.Current.MainWindow, Main).contenido
            If marco.NavigationService.CanGoBack Then
                marco.NavigationService.GoBack()
            Else
                marco.Content = Nothing
                CType(Application.Current.MainWindow, Main).logo.Visibility = Windows.Visibility.Visible
            End If
        End Sub

#End Region

    End Class

End Namespace