﻿Imports System.Xml.Linq
Imports System.Net

Namespace UTIL

    ''' <summary>
    ''' Clase que contiene los métodos referentes a la visualización de mapas y obtención de localizaciones
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 30/05/2013
    ''' </remarks>
    Public Class Google

        ''' <summary>
        ''' Método que muestra un mapa estático de google maps
        ''' </summary>
        ''' <param name="lat">Latitud de la posición mostrar</param>
        ''' <param name="lng">Longitud de la posición mostrar</param>
        ''' <returns>
        ''' BitmapImage con la imagen del mapa
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function ShowMapUsingLatLng(ByVal lat As String, ByVal lng As String) As BitmapImage
            Try
                Return ShowMapUsingLocation(lat & "," & lng)
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que muestra un mapa estático de google maps
        ''' </summary>
        ''' <param name="location">Localización a mostrar</param>
        ''' <returns>
        ''' BitmapImage con la imagen del mapa
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function ShowMapUsingLocation(ByVal location As String) As BitmapImage
            Try
                Dim bmpImage As New BitmapImage()

                Dim mapURL As String = "http://maps.googleapis.com/maps/api/staticmap?" & _
                    "size=570x270&markers=size:mid%7Ccolor:red%7Clabel:C%7C" & location & _
                    "&zoom=17&maptype=ROADMAP&sensor=false"

                bmpImage.BeginInit()
                bmpImage.UriSource = New Uri(mapURL)
                bmpImage.EndInit()

                Return bmpImage
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que obtiene los datos de posición de una localización
        ''' </summary>
        ''' <param name="location">Localización a buscar</param>
        ''' <param name="latitude">Latitud de la localización a devolver</param>
        ''' <param name="longitude">Longitud de la localización a devolver</param>
        ''' <returns>
        ''' Cadena con el error si ha fallado la consulta o vacía si ha encontrado la localización
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function GetLatLng(ByRef location As String, ByRef latitude As String, ByRef longitude As String) As String
            Try
                Dim geoDoc As XDocument
                Dim geocodeURL As String = "http://maps.googleapis.com/maps/api/" & _
                    "geocode/xml?address=" & location & "&sensor=false"
                Try
                    geoDoc = XDocument.Load(geocodeURL)
                Catch ex As WebException
                    Return "msg_err_internet"
                End Try
                Dim responseStatus = geoDoc...<status>.Single.Value()
                If (responseStatus = "OK") Then
                    location = geoDoc...<formatted_address>(0).Value()
                    latitude = geoDoc...<location>(0).Element("lat").Value()
                    longitude = geoDoc...<location>(0).Element("lng").Value()

                ElseIf (responseStatus = "ZERO_RESULTS") Then
                    Return "msg_err_resultados"
                End If
                Return String.Empty
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

    End Class

End Namespace