﻿Imports Maraton.Admin.UTIL.Mensaje
Imports log4net

Namespace UTIL

    ''' <summary>
    ''' Clase que contiene los métodos que escriben distintas trazas de log en la aplicación
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 30/05/2013
    ''' </remarks>
    Public Class Log

        ''' <summary>
        ''' Método que escribe una traza de error en el log y alerta al usuario del error
        ''' </summary>
        ''' <param name="ex">Excepción a escribir</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub LogError(ByVal ex As Exception)
            Dim log As ILog = LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType)
            log.Error(ex.Message, ex)
            MensajeError("msg_error")
        End Sub

        ''' <summary>
        ''' Método que escribe una traza de alerta en el log 
        ''' </summary>
        ''' <param name="key">Clave del mensaje a escribir</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub LogWarn(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "")
            Dim log As ILog = LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType)
            If replaceOldStr.Equals(String.Empty) Then
                log.Warn(MensajeResource(key))
            Else
                log.Warn(MensajeResource(key).Replace(replaceOldStr, replaceNewStr))
            End If
        End Sub

        ''' <summary>
        ''' Método que escribe una traza de información en el log 
        ''' </summary>
        ''' <param name="key">Clave del mensaje a escribir</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub LogInfo(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "")
            Dim log As ILog = LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType)
            If replaceOldStr.Equals(String.Empty) Then
                log.Info(MensajeResource(key))
            Else
                log.Info(MensajeResource(key).Replace(replaceOldStr, replaceNewStr))
            End If
        End Sub

    End Class

End Namespace