﻿Namespace UTIL

    ''' <summary>
    ''' Clase que contiene los métodos que lanzan distintos tipos de mensaje en la aplicación
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 30/05/2013
    ''' </remarks>
    Public Class Mensaje

        ''' <summary>
        ''' Método que lanza un mensaje de información en el sistema
        ''' </summary>
        ''' <param name="key">Clave del mensaje a mostrar</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub MensajeInfo(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "")
            If replaceOldStr.Equals(String.Empty) Then
                MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema"), _
                    MessageBoxButton.OK, MessageBoxImage.Information, MessageBoxResult.OK)
            Else
                MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema").Replace(replaceOldStr, replaceNewStr), _
                    MessageBoxButton.OK, MessageBoxImage.Warning, MessageBoxResult.OK)
            End If
        End Sub

        ''' <summary>
        ''' Método que lanza un mensaje de alerta en el sistema
        ''' </summary>
        ''' <param name="key">Clave del mensaje a mostrar</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub MensajeWarn(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "")
            If replaceOldStr.Equals(String.Empty) Then
                MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema"), _
                    MessageBoxButton.OK, MessageBoxImage.Warning, MessageBoxResult.OK)
            Else
                MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema").Replace(replaceOldStr, replaceNewStr), _
                    MessageBoxButton.OK, MessageBoxImage.Warning, MessageBoxResult.OK)
            End If
        End Sub

        ''' <summary>
        ''' Método que lanza un mensaje de error en el sistema
        ''' </summary>
        ''' <param name="key">Clave del mensaje a mostrar</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub MensajeError(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "")
            If replaceOldStr.Equals(String.Empty) Then
                MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema"), _
                    MessageBoxButton.OK, MessageBoxImage.Error, MessageBoxResult.OK)
            Else
                MessageBox.Show(MensajeResource(key).Replace(replaceOldStr, replaceNewStr), MensajeResource("msg_sistema"), _
                    MessageBoxButton.OK, MessageBoxImage.Error, MessageBoxResult.OK)
            End If
        End Sub

        ''' <summary>
        ''' Método que lanza un mensaje de confirmación en el sistema
        ''' </summary>
        ''' <param name="key">Clave del mensaje a mostrar</param>
        ''' <param name="replaceOldStr">Parámetro con la cadena a reemplazar en el mensaje</param>
        ''' <param name="replaceNewStr">Parámetro con la cadena nuevo en el mensaje</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function MensajeConfirmacion(ByVal key As String, Optional ByVal replaceOldStr As String = "", Optional ByVal replaceNewStr As String = "") As Boolean
            If replaceOldStr.Equals(String.Empty) Then
                Return CBool(MessageBox.Show(MensajeResource(key), MensajeResource("msg_sistema"), _
                    MessageBoxButton.YesNo, MessageBoxImage.Question, MessageBoxResult.Yes))
            Else
                Return CBool(MessageBox.Show(MensajeResource(key).Replace(replaceOldStr, replaceNewStr), MensajeResource("msg_sistema"), _
                    MessageBoxButton.YesNo, MessageBoxImage.Question, MessageBoxResult.Yes))
            End If
        End Function

        ''' <summary>
        ''' Método que obtiene un mensaje del almacen de recursos
        ''' </summary>
        ''' <param name="key">Clave del mensaje</param>
        ''' <returns>
        ''' Mensaje obtenido del almacén de recursos
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function MensajeResource(ByVal key As String) As String
            Try
                Return CStr(Application.Current.Resources.MergedDictionaries(0).Item(key))
            Catch ex As Exception
                Throw (ex)
            End Try

        End Function

    End Class

End Namespace