Imports System.Text.RegularExpressions
Imports System.Windows.Controls
Imports System.Windows.Input

Namespace UTIL

    ''' <summary>
    ''' Clase que contiene los métodos de validación para los datos que introduce el usuario
    ''' así como los que aplican el estilo en función de si cumplen la validación o nó
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 30/05/2013
    ''' </remarks>
    Public Class Validacion

        ''' <summary>
        ''' Método que obtiene un estilo determinado
        ''' </summary>
        ''' <param name="key">Clave del estilo a devolver</param>
        ''' <returns>
        ''' Estilo a asignar a un control
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Private Shared Function Estilo(ByVal key As String) As Style
            Try
                Return CType(Application.Current.Resources.Item(key), Style)
            Catch ex As Exception
                Throw (ex)
            End Try
        End Function

        ''' <summary>
        ''' Método que asigna el estilo de campo requerido al label y control enviado como argumento
        ''' </summary>
        ''' <param name="ctrlEtiqueta">Label a asignar el estilo</param>
        ''' <param name="ctrlValue">Control a asignar el estilo</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub MarcarCampos(ByVal ctrlEtiqueta As Label, ByVal ctrlValue As Control)
            Try
                If ctrlValue.GetType().Equals(GetType(TextBox)) Then
                    ctrlValue.Style = Estilo("txtError")
                ElseIf ctrlValue.GetType().Equals(GetType(PasswordBox)) Then
                    ctrlValue.Style = Estilo("passError")
                ElseIf ctrlValue.GetType().Equals(GetType(ComboBox)) Then
                    ctrlValue.Style = Estilo("cbError")
                ElseIf ctrlValue.GetType().Equals(GetType(DatePicker)) Then
                    ctrlValue.Style = Estilo("dpError")
                End If
                ctrlEtiqueta.Style = Estilo("lblError")
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que anula los estilos al label y control enviado como argumento
        ''' </summary>
        ''' <param name="ctrlEtiqueta">Label a eliminar el estilo</param>
        ''' <param name="ctrlValue">Control a eliminar el estilo</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub DesmarcarCampos(ByVal ctrlEtiqueta As Label, ByVal ctrlValue As Control)
            Try
                ctrlEtiqueta.Style = Nothing
                ctrlValue.Style = Nothing
            Catch ex As Exception
                Throw (ex)
            End Try
        End Sub

        ''' <summary>
        ''' Método que comprueba que las pulsaciones tecleadas sean números
        ''' </summary>
        ''' <param name="e">Evento que lanza al método</param>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Sub SoloNumeros(ByRef e As System.Windows.Input.KeyEventArgs)
            If (e.Key >= Key.D0 AndAlso e.Key <= Key.D9 Or e.Key >= Key.NumPad0 AndAlso e.Key <= Key.NumPad9) Then
                e.Handled = False
            Else
                e.Handled = True
            End If
        End Sub

        ''' <summary>
        ''' Método que realiza la validación en cuanto al formato de una dirección de correo electrónico mediante
        ''' expresiones regulares
        ''' </summary>
        ''' <param name="strDireccion">Cadena que contiene el correo a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si el formato es correcto (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function Correo(ByVal strDireccion As String) As Boolean
            If Not Regex.IsMatch(strDireccion, "^([\w-]+\.)*?[\w-]+@[\w-]+\.([\w-]+\.)*?[\w]+$") Then
                MensajeError("msg_formato_correo")
                Return False
            Else
                Return True
            End If
        End Function

        ''' <summary>
        ''' Método que realiza la validación de un teléfono mediante expresiones regulares
        ''' </summary>
        ''' <param name="strTelefono">Cadena que contiene el teléfono a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si el formato es correcto (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function Telefono(ByVal strTelefono As String) As Boolean
            If Not Regex.IsMatch(strTelefono, "^[9|6|8][0-9]{8}$") Then
                MensajeError("msg_formato_telefono")
                Return False
            Else
                Return True
            End If
        End Function

        ''' <summary>
        ''' Método que realiza la validación de la edad (ha de ser un entero mayor o igual a 5)
        ''' </summary>
        ''' <param name="strEdad">Cadena que contiene la edad a comprobar</param>
        ''' <returns>
        ''' Booleano que indica si el formato es correcto (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 30/05/2013
        ''' </remarks>
        Public Shared Function Edad(ByVal strEdad As String) As Boolean
            If CInt(strEdad) < 5 Then
                MensajeError("msg_formato_edad")
                Return False
            Else
                Return True
            End If
        End Function

    End Class

End Namespace