Imports System.Diagnostics.CodeAnalysis
Imports System.Security.Principal
Imports System.Web.Routing
Imports Maraton.UTIL.Log
Imports Maraton.UTIL.Utilidad
Imports Maraton.UTIL

Namespace Maraton.Controller

    ''' <summary>
    ''' Clase controlador que gestiona los redireccionamientos de las distintas vistas de la aplicación
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    <HandleError()> _
    Public Class AccesoController
        Inherits System.Web.Mvc.Controller

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/LogOn
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "LogOn" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LogOn() As ActionResult
            Return View()
        End Function

        ''' <summary>
        ''' Método que valida si un usuario puede acceder a la aplicación
        ''' </summary>
        ''' <param name="model">Objeto Usuario de la vista que intenta acceder a la aplicación</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        <HttpPost()> _
        Public Function LogOn(ByVal model As USUARIO) As ActionResult
            Try
                If ModelState.IsValid Then
                    Dim md5Pass As String = UTIL.Utilidad.Encriptar(model.DS_PASSWORD)
                    Dim objModel As New dbConnection
                    Dim objUsu As USUARIO = (From p In objModel.USUARIO Where p.DS_LOGIN = model.DS_LOGIN And p.DS_PASSWORD = md5Pass And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p).FirstOrDefault
                    If Not objUsu Is Nothing Then
                        FormsAuthentication.SetAuthCookie(model.DS_LOGIN, False)
                        Session.Add("USUARIO", objUsu)
                        UTIL.Log.LogInfo("EL USUARIO " & model.DS_LOGIN & " HA INICIADO SESIÓN")
                        Return RedirectToAction("Index", "Home")
                    Else
                        UTIL.Log.LogInfo("EL USUARIO " & model.DS_LOGIN & " HA INTENTADO INICIAR SESIÓN")
                        ModelState.AddModelError("", Resources.Messages.msg_rincon_login_error)
                    End If
                End If

                ' Si llegamos a este punto, es que se ha producido un error y volvemos a mostrar el formulario
                Return View(model)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/LogOff. 
        ''' Limpia la sesión y redirecciona a la pantalla principal
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Index" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function LogOff() As ActionResult
            Try
                FormsAuthentication.SignOut()
                Session.Clear()
                Return RedirectToAction("Index", "Home")
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/Registro. 
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Registro" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function Registro() As ActionResult
            Return View()
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/Registro. 
        ''' Realiza las validaciones pertinentes y el guardado de un nuevo usuario
        ''' </summary>
        ''' <param name="coll">Colección con los controles del formulario que envía la petición</param>
        ''' <param name="model">Objeto Usuario que intenta registrarse con las datos del mismo</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        <HttpPost()> _
        Public Function Registro(ByVal coll As Mvc.FormCollection, ByVal model As USUARIO) As ActionResult
            Try
                If ModelState.IsValid Then
                    If coll(6).Equals(model.DS_PASSWORD) Then
                        If Validacion.Correo(model.DS_EMAIL) Then
                            If Validacion.Edad(model.EN_EDAD) Then
                                If ValidarLogin(model.DS_LOGIN) Then
                                    Dim db As New dbConnection
                                    model.DS_USUALTA = model.DS_LOGIN
                                    model.DS_PASSWORD = UTIL.Utilidad.Encriptar(model.DS_PASSWORD)
                                    db.AddToUSUARIO(model)
                                    db.SaveChanges()
                                    ViewData("Resultado") = Resources.Messages.msg_registro_ok
                                    Return RedirectToAction("LogOn")
                                Else
                                    ModelState.AddModelError("", Resources.Messages.msg_error_login)
                                    ViewData("Resultado") = String.Empty
                                End If
                            Else
                                ModelState.AddModelError("", Resources.Messages.msg_formato_edad)
                                ViewData("Resultado") = String.Empty
                            End If
                        Else
                            ModelState.AddModelError("", Resources.Messages.msg_formato_correo)
                            ViewData("Resultado") = String.Empty
                        End If
                    Else
                        ModelState.AddModelError("", Resources.Messages.msg_validacion_pass)
                        ViewData("Resultado") = String.Empty
                    End If
                End If

                Return View(model)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que valida que exista un nombre de usuario en la base de datos
        ''' </summary>
        ''' <param name="strLogin">Cadena con el nombre de usuario a validar</param>
        ''' <returns>
        ''' Booleano que indica si el login existe (True) o no (False)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private Function ValidarLogin(ByVal strLogin As String) As Boolean
            Try
                Dim db As New dbConnection
                Dim objUsu As USUARIO = (From p In db.USUARIO Where p.DS_LOGIN = strLogin Select p).FirstOrDefault
                If objUsu Is Nothing Then
                    Return True
                Else
                    Return False
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/Recordar
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Recordar" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Public Function Recordar() As ActionResult
            Return View()
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Acceso/Registro. 
        ''' Realiza las validaciones pertinentes y el guardado de un nuevo usuario
        ''' </summary>
        ''' <param name="model">Objeto Usuario de la vista que solicita un reseteo de contraseña</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        <HttpPost()> _
        Public Function Recordar(ByVal model As USUARIO) As ActionResult
            Try
                Dim db As New dbConnection
                Dim objUsu As USUARIO = (From p In db.USUARIO Where p.DS_LOGIN = model.DS_LOGIN And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p).FirstOrDefault
                If objUsu Is Nothing Then
                    LogWarn(Resources.Messages.log_usuario_intento_reseteo.Replace("%1", model.DS_LOGIN))
                    'ModelState.AddModelError("", Resources.Messages.msg_login_no_existe)
                    ViewData("Resultado") = Resources.Messages.msg_login_no_existe
                Else
                    Utilidad.EnviarCorreo(model.DS_LOGIN)
                    LogInfo(Resources.Messages.log_usuario_reseteo.Replace("%1", model.DS_LOGIN))
                    'ModelState.AddModelError("", Resources.Messages.label_pass_mail_envio)
                    ViewData("Resultado") = Resources.Messages.label_pass_mail_envio
                End If
                Return View()
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

    End Class

End Namespace
