Imports Maraton.UTIL.Log
Imports System.IO

Namespace Maraton.Controller

    ''' <summary>
    ''' Clase controlador que gestiona los redireccionamientos de las distintas vistas de la aplicación
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    <HandleError()>
    Public Class HomeController
        Inherits System.Web.Mvc.Controller

        ''' <summary>
        ''' Variable con la conexión de base de datos que utilizamos
        ''' </summary>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Private db As New dbConnection

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Index
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Index" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Index() As ActionResult
            Return View()
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Ofertas
        ''' Devuelve las ofertas actuales
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Ofertas" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Ofertas() As ActionResult
            Try
                Dim listOfertas As New List(Of OFERTA)
                listOfertas = (From p In db.OFERTA Where p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now Select p Order By p.DT_FECBAJA Ascending, p.DT_FECALTA Descending).ToList
                Return View(listOfertas)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Competiciones
        ''' Devuelve las competiciones
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Competiciones" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Competiciones() As ActionResult
            Try
                Dim model As List(Of COMPETICION) = (From o In db.COMPETICION).ToList
                Dim fName As String = String.Empty
                For c As Integer = 0 To model.Count - 1
                    fName = Path.Combine(Server.MapPath("~/Kml/"), model(c).ID_COMPETICION & ".kml")
                    Dim objWriter As New StreamWriter(fName)
                    objWriter.Write(model(c).OB_RECORRIDO)
                    objWriter.Close()
                Next
                Return View(db.COMPETICION)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Instalaciones
        ''' Devuelve las instalaciones dadas de alta
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Instalaciones" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Instalaciones() As ActionResult
            Try
                Dim inst As New List(Of INSTALACION)
                inst = (From p In db.INSTALACION Where p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now Select p Order By p.ID_CENTRO Ascending).ToList
                Return View(inst)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Premios
        ''' Devuelve los premios
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Premios" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Premios() As ActionResult
            Return View(db.PREMIO)
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Patrocinadores
        ''' Devuelve los patrocinadores dados de alta
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Patrocinadores" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Patrocinadores() As ActionResult
            Try
                Dim patro As New List(Of PATROCINADOR)
                patro = (From p In db.PATROCINADOR Where p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now Select p Order By p.DS_TITULO Ascending).ToList
                Return View(patro)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Home/Contacto
        ''' Devuelve los datos de los centros del club
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Contacto" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Contacto() As ActionResult
            Try
                Dim centro As New List(Of CENTRO)
                centro = (From p In db.CENTRO Where p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now Select p Order By p.DS_TITULO Ascending).ToList
                Return View(centro)
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que obtiene una imagen de la base de datos de una instalación
        ''' </summary>
        ''' <param name="ID">Id de la instalación a obtener la imagen</param>
        ''' <returns>
        ''' ActionResult con el fichero obtenido
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function GetImageInst(ByVal ID As Integer) As ActionResult
            Try
                Dim imageData As Byte() = (From p In db.INSTALACION Where p.ID_INSTALACION = ID Select p).FirstOrDefault.OB_IMAGEN
                Return File(imageData, "image/jpeg", "")
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que obtiene una imagen de la base de datos de un premio
        ''' </summary>
        ''' <param name="ID">Id del premio a obtener la imagen</param>
        ''' <returns>
        ''' ActionResult con el fichero obtenido
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function GetImagePremio(ByVal ID As Integer) As ActionResult
            Try
                Dim imageData As Byte() = (From p In db.PREMIO Where p.ID_PREMIO = ID Select p).FirstOrDefault.OB_PREMIO
                Return File(imageData, "image/jpeg", "")
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que obtiene una imagen de la base de datos de un patrocinador
        ''' </summary>
        ''' <param name="ID">Id del patrocinador a obtener la imagen</param>
        ''' <returns>
        ''' ActionResult con el fichero obtenido
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function GetImagePatro(ByVal ID As Integer) As ActionResult
            Try
                Dim imageData As Byte() = (From p In db.PATROCINADOR Where p.ID_PATROCINADOR = ID Select p).FirstOrDefault.OB_LOGOTIPO
                Return File(imageData, "image/jpeg", "")
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

    End Class

End Namespace