Imports CrystalDecisions.CrystalReports.Engine
Imports CrystalDecisions.Shared
Imports Maraton.UTIL.Log
Imports Maraton.UTIL
Imports System.Data.SqlTypes
Imports System.Xml
Imports System.IO
Imports System.Data.Objects

Namespace Maraton.Controller

    ''' <summary>
    ''' Clase controlador que gestiona los redireccionamientos de las distintas vistas de la aplicación
    ''' En todos los métodos se comprueba que el usuario esté registrado en el sistema, si no es el caso
    ''' se le redirecciona a una pantalla en el que se le informa de la validación
    ''' </summary>
    ''' <remarks>
    ''' Alberto Morgado Contreras 
    ''' amorgadoc@uoc.edu
    ''' 10/06/2013
    ''' </remarks>
    <HandleError()>
    Public Class RinconController
        Inherits System.Web.Mvc.Controller

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/Estadisticas
        ''' Obtiene las estadísticas de las carreras de un corredor
        ''' </summary>
        ''' <param name="model">Objeto VW_ESTADISTICAS con las estadísticas del usuario logado</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Estadisticas(ByVal model As VW_ESTADISTICAS) As ActionResult
            Try
                If Session.Count > 0 Then
                    Dim db As New dbConnection
                    Dim idUsu As Double = CType(Session("USUARIO"), USUARIO).ID_USUARIO
                    model = (From p In db.VW_ESTADISTICAS Where p.ID_USUARIO = idUsu Select p).FirstOrDefault
                    Return (View(model))
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/Inscripciones
        ''' Obtiene las competiciones del club en relación con el usuario logado
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Inscripciones() As ActionResult
            Try
                If Session.Count > 0 Then
                    If Not TempData("Resultado") Is Nothing Then
                        ViewData("Resultado") = TempData("Resultado")
                    End If
                    Dim db As New dbConnection
                    Dim model As List(Of COMPETICION) = (From p In db.COMPETICION Select p Order By p.DS_TITULO Ascending).ToList
                    Dim modIns As INSCRIPCION
                    Dim idUsu As Double = CType(Session("USUARIO"), USUARIO).ID_USUARIO
                    Dim idComp As Integer
                    For c As Integer = 0 To model.Count - 1
                        idComp = model(c).ID_COMPETICION
                        modIns = (From p In db.INSCRIPCION Where p.ID_USUARIO = idUsu And p.ID_COMPETICION = idComp Select p).FirstOrDefault
                        If modIns Is Nothing Then
                            model(c).DS_COMPETICION = "0"
                        End If
                    Next
                    Return View(model)
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que realiza las validaciones y en caso de superarlas, inscribe al usuario logado en la competición solicitada
        ''' </summary>
        ''' <param name="id">Id de la competición en la que el usuario solicita inscribirse</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Inscripcion(ByVal id As Integer) As ActionResult
            Try
                If Session.Count > 0 Then
                    Dim db As New dbConnection
                    Dim objCom As COMPETICION = (From p In db.COMPETICION Select p Where p.ID_COMPETICION = id).FirstOrDefault
                    If objCom.DT_FECHA > Now Then
                        Dim ins As New INSCRIPCION
                        With ins
                            .ID_USUARIO = CType(Session(0), USUARIO).ID_USUARIO
                            .ID_COMPETICION = id
                            .DS_USUALTA = CType(Session(0), USUARIO).DS_LOGIN
                        End With
                        db.AddToINSCRIPCION(ins)
                        db.SaveChanges()
                        TempData("Resultado") = Resources.Messages.msg_registro_ok
                    Else
                        TempData("Resultado") = Resources.Messages.msg_fuera_plazo
                    End If
                    Return RedirectToAction("Inscripciones")
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que genera el PDF con el dorsal del corredor logado 
        ''' </summary>
        ''' <param name="id">Id de la competición en la que el usuario solicita el dorsal</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function ViewPdf(ByVal id As Integer) As ActionResult
            Try

                If Session.Count > 0 Then
                    Dim db As New dbConnection
                    Dim patrocinadores As New List(Of String)
                    patrocinadores = (From p In db.VW_PATROCINADORES_COMP Where p.ID_COMPETICION = id Select p.DS_TITULO).ToList
                    Dim sbPatro As New StringBuilder(String.Empty)
                    If patrocinadores.Count > 0 Then
                        For c As Integer = 0 To patrocinadores.Count - 1
                            sbPatro.Append(patrocinadores(c))
                            sbPatro.Append(", ")
                        Next
                        sbPatro.Remove(sbPatro.Length - 2, 2)
                    End If
                    Dim idUsu As Double = CType(Session(0), USUARIO).ID_USUARIO
                    Dim model As INSCRIPCION = (From p In db.INSCRIPCION Where p.ID_COMPETICION = id And p.ID_USUARIO = idUsu Select p).FirstOrDefault
                    Dim objRpt As New Dorsal
                    Dim arrayParametros As New Dictionary(Of String, Object)
                    With objRpt
                        arrayParametros.Add(.Parameter_Numero.ParameterFieldName, model.EN_DORSAL)
                        arrayParametros.Add(.Parameter_Colabora.ParameterFieldName, Resources.Messages.label_pdf_colabora)
                        arrayParametros.Add(.Parameter_Competicion.ParameterFieldName, model.COMPETICIONReference.Value.DS_TITULO)
                        arrayParametros.Add(.Parameter_Fecha.ParameterFieldName, model.COMPETICIONReference.Value.DT_FECHA)
                        arrayParametros.Add(.Parameter_Patrocinador.ParameterFieldName, sbPatro.ToString)
                    End With
                    Report.CargarInforme(arrayParametros)

                    Return New EmptyResult()
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/Comentarios
        ''' Devuelve los comentarios junto con sus recorridos
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Comentarios" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Comentarios() As ActionResult
            Try
                If Session.Count > 0 Then
                    Dim fName As String
                    Dim db As New dbConnection
                    Dim model As New List(Of COMENTARIO)
                    model = (From p In db.COMENTARIO Where p.BO_ACTIVO = "1" And (p.DT_FECBAJA Is Nothing Or p.DT_FECBAJA > DateTime.Now) Select p Order By p.DT_FECHA Descending).ToList
                    For c As Integer = 0 To model.Count - 1
                        fName = Path.Combine(Server.MapPath("~/Kml/"), model(c).ID_COMENTARIO & ".kml")
                        Dim objWriter As New StreamWriter(fName)
                        objWriter.Write(model(c).OB_RECORRIDO)
                        objWriter.Close()
                    Next
                    Return View(model)
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/NuevoComentario
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "NuevoComentario" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function NuevoComentario() As ActionResult
            Try
                If Session.Count > 0 Then
                    Return View()
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/NuevoComentario
        ''' Método que guarda un comentario nuevo junto con su recorrido
        ''' </summary>
        ''' <param name="file">Fichero con el recorrido a almacenar</param>
        ''' <param name="model">Objeto comentario que contiene los datos a guardar</param>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        <HttpPost()> _
        Function NuevoComentario(ByVal file As HttpPostedFileBase, ByVal model As COMENTARIO) As ActionResult
            Try
                If Session.Count > 0 Then
                    If ModelState.IsValid Then
                        If Not file Is Nothing andalso Not file.FileName.ToLower.EndsWith(".kml") Then
                            ViewData("Resultado") = Resources.Messages.msg_recorrido_adjunto
                        Else
                            Dim objModel As New dbConnection
                            With model
                                .BO_ACTIVO = "0"
                                .DS_USUALTA = CType(Session("USUARIO"), USUARIO).DS_LOGIN
                                If Not file Is Nothing Then
                                    If (file.InputStream.Length > 4194304) Then
                                        ModelState.AddModelError("", Resources.Messages.msg_imagen_tamanyo)
                                    Else
                                        Dim b As BinaryReader = New BinaryReader(file.InputStream)
                                        Dim binData As Byte() = b.ReadBytes(CInt(file.InputStream.Length))

                                        Dim fichero As String = Encoding.UTF8.GetString(binData)
                                        If fichero.StartsWith("<?xml") Then
                                            fichero = fichero.Remove(0, fichero.IndexOf(">") + 1)
                                        End If
                                        .OB_RECORRIDO = fichero
                                    End If
                                End If
                                .ID_USUARIO = CType(Session("USUARIO"), USUARIO).ID_USUARIO
                            End With
                            objModel.AddToCOMENTARIO(model)
                            objModel.SaveChanges()
                            ViewData("Resultado") = Resources.Messages.msg_registro_ok
                            Return RedirectToAction("Comentarios")
                        End If
                    End If
                    Return View()
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/Datos
        ''' Muestra por pantalla los datos del usuario logado
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista "Datos" a mostrar
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        Function Datos() As ActionResult
            Try
                If Session.Count > 0 Then
                    Dim objModel As New dbConnection
                    Dim idUsu As Double = CType(Session("USUARIO"), USUARIO).ID_USUARIO
                    Dim model As USUARIO = (From p In objModel.USUARIO Where p.ID_USUARIO = idUsu Select p).FirstOrDefault
                    Return View(model)
                Else
                    Return View("NoAutorizado")
                End If
            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

        ''' <summary>
        ''' Método que gestiona la petición a la URL /Rincon/Datos
        ''' Guarda los datos del usuario logado una vez realizadas las validaciones oportunas
        ''' </summary>
        ''' <returns>
        ''' ActionResult con la vista a mostrar (la misma en la que se encuentra)
        ''' </returns>
        ''' <remarks>
        ''' Alberto Morgado Contreras 
        ''' amorgadoc@uoc.edu
        ''' 10/06/2013
        ''' </remarks>
        <HttpPost()> _
        Function Datos(ByVal coll As Mvc.FormCollection, ByVal model As USUARIO) As ActionResult
            Try
                If Session.Count > 0 Then
                    If ModelState.IsValid Then
                        If coll(6).Equals(model.DS_PASSWORD) Then
                            If Validacion.Correo(model.DS_EMAIL) Then
                                If Validacion.Edad(model.EN_EDAD) Then
                                    Dim objModel As New dbConnection
                                    Dim idUsu As Double = CType(Session("USUARIO"), USUARIO).ID_USUARIO
                                    Dim modelOld As USUARIO = (From p In objModel.USUARIO Where p.ID_USUARIO = idUsu Select p).FirstOrDefault
                                    With modelOld
                                        .DS_NOMBRE = model.DS_NOMBRE
                                        .DS_APELLIDO1 = model.DS_APELLIDO1
                                        .DS_APELLIDO2 = model.DS_APELLIDO2
                                        .DS_PASSWORD = UTIL.Utilidad.Encriptar(model.DS_PASSWORD)
                                        .DS_EMAIL = model.DS_EMAIL
                                        .DS_USUMOD = model.DS_LOGIN

                                        model.CH_SEXO = .CH_SEXO
                                        model.DS_LOGIN = .DS_LOGIN
                                    End With
                                    objModel.SaveChanges()
                                    ViewData("Resultado") = Resources.Messages.msg_registro_ok
                                Else
                                    ModelState.AddModelError("", Resources.Messages.msg_formato_edad)
                                End If
                            Else
                                ModelState.AddModelError("", Resources.Messages.msg_formato_correo)
                            End If
                        Else
                            ModelState.AddModelError("", Resources.Messages.msg_validacion_pass)
                        End If
                    End If
                    Return View(model)
                Else
                    Return View("NoAutorizado")
                End If

            Catch ex As Exception
                LogError(ex)
                Return Nothing
            End Try
        End Function

    End Class

End Namespace